# 🧑‍🍳 Cookbooks

Community contributed cookbooks for KitchenAI can be found here

[KitchenAI Community](https://github.com/epuerta9/kitchenai-community)

Cookbooks are kitchenAI recipes and apps that provide a unique techniques using the KitchenAI framework.


## 📚 **llama-index starter**

A starter cookbook for using llama-index with KitchenAI.

[llama-index starter](https://github.com/epuerta9/kitchenai-community/blob/main/src/kitchenai_community/llama_index_starter/README.md)


## 📚 **llama-index toolhouse and cloudflare AI gateway**

A cookbook for using llama-index with the cloudflare AI gateway.

[llama-index toolhouse and cloudflare AI gateway](https://github.com/epuerta9/kitchenai-community/tree/main/src/kitchenai_community/llama_index_toolhouse_cloudflare)


